@@ -1,5 +1,5 @@
 
-# $Id: ConditionalTree.R 467 2012-02-16 14:18:23Z thothorn $
+# $Id: ConditionalTree.R 518 2013-05-31 17:28:58Z thothorn $
 
 ### the fitting procedure
 ctreefit <- function(object, controls, weights = NULL, fitmem = NULL, ...) {
@@ -168,7 +168,8 @@ ctreedpp <- function(formula, data = list(), subset = NULL,
     if (any(is.na(response)))
         stop("missing values in response variable not allowed")
 
-    resp <- initVariableFrame(response, trafo = ytrafo, response = TRUE)
+    resp <- initVariableFrame(response, trafo = ytrafo, response = TRUE,
+                              scores = scores)
 
     RET <- new("LearningSampleFormula", inputs = inp, responses = resp,
                weights = rep(1, inp@nobs), nobs = inp@nobs,
